@@ -3,6 +3,7 @@ from ladybug_geometry.geometry2d.pointvector import Point2D
 from ladybug_geometry.geometry2d.polygon import Polygon2D
 from ladybug.color import Color
 from ladybug_display.geometry2d.polygon import DisplayPolygon2D
+from ladybug_display.altnumber import default
 
 
 def test_display_p_gon2d_init():
@@ -13,7 +14,8 @@ def test_display_p_gon2d_init():
     str(p_gon)  # test the string representation of the p_gon
 
     assert p_gon.color == grey
-    assert p_gon.display_mode == 'Surface'
+    assert p_gon.line_width == default
+    assert p_gon.line_type == 'Continuous'
     assert isinstance(p_gon.vertices, tuple)
     assert len(p_gon.vertices) == 4
     for point in p_gon.vertices:
@@ -23,9 +25,11 @@ def test_display_p_gon2d_init():
 
     blue = Color(0, 0, 100)
     p_gon.color = blue
-    p_gon.display_mode = 'Wireframe'
+    p_gon.line_width = 2
+    p_gon.line_type = 'Dashed'
     assert p_gon.color == blue
-    assert p_gon.display_mode == 'Wireframe'
+    assert p_gon.line_width == 2
+    assert p_gon.line_type == 'Dashed'
 
 
 def test_p_gon2d_to_from_dict():
@@ -33,7 +37,8 @@ def test_p_gon2d_to_from_dict():
     grey = Color(100, 100, 100)
     pts = (Point2D(0, 0), Point2D(0, 2), Point2D(2, 2), Point2D(2, 0))
     p_gon = DisplayPolygon2D(Polygon2D(pts), grey)
-    p_gon.display_mode = 'Wireframe'
+    p_gon.line_width = 2
+    p_gon.line_type = 'Dashed'
     p_gon_dict = p_gon.to_dict()
     new_p_gon = DisplayPolygon2D.from_dict(p_gon_dict)
     assert isinstance(new_p_gon, DisplayPolygon2D)
